Exception: Momento::Error::PermissionError

Inherits:
RuntimeError
  • Object
show all
Includes:
Momento::Error
Defined in:
lib/momento/error/types.rb

Overview

Insufficient permissions to perform an operation on a cache.

Instance Attribute Summary

Attributes included from Momento::Error

#cause, #context, #details, #transport_details

Instance Method Summary collapse

Methods included from Momento::Error

#to_s

Instance Method Details

#error_codeSymbol

A Momento-specific code for the type of error.

Returns:

  • (Symbol)


235
236
237
# File 'lib/momento/error/types.rb', line 235

def error_code
  :PERMISSION_ERROR
end

#messageString

The error message.

Returns:

  • (String)


240
241
242
# File 'lib/momento/error/types.rb', line 240

def message
  "Insufficient permissions to perform an operation on a cache: #{details}"
end